==> airbridge_flutter_sdk-1.0.0.tar.gz: android/src/main/java/co/ab180/airbridge/flutter/Get.java <==
package co.ab180.airbridge.flutter;

import java.util.ArrayList;
import java.util.HashMap;

public class Get {
    static <T> T type(Class<T> type, Object object) {
        if (object == null || type.isInstance(object)) {
            return type.cast(object);
        } else {
            return null;
        }
    }

    static <T> T type(Class<T> type, HashMap map, String key) {
        if (map == null) {
            return null;
        }

        Object object = map.get(key);

        return Get.type(type, object);
    }

    static <T> T type(Class<T> type, ArrayList list, int index) {
        if (list == null || index < 0 || index > list.size()) {
            return null;
        }

        Object object = list.get(index);

        return Get.type(type, object);
    }

    static <T extends Number> T type(Class<T> type, Number number) {
        if (number == null) {
            return null;
        }

        if (type.isAssignableFrom(Number.class)) {
            return type.cast(number);
        }

        if(type.isAssignableFrom(Byte.class)) {

            return type.cast(number.byteValue());

        } else if (type.isAssignableFrom(Short.class)) {

            return type.cast(number.shortValue());

        } else if (type.isAssignableFrom(Integer.class)) {

            return type.cast(number.intValue());

        } else if (type.isAssignableFrom(Long.class)) {

            return type.cast(number.longValue());

        } else if (type.isAssignableFrom(Float.class)) {

            return type.cast(number.floatValue());

        } else if (type.isAssignableFrom(Double.class)) {

            return type.cast(number.doubleValue());

        }

        return null;
    }
}

==> airbridge_flutter_sdk-1.1.1.tar.gz: android/src/main/java/co/ab180/airbridge/flutter/Get.java <==
package co.ab180.airbridge.flutter;

import java.util.List;
import java.util.Map;

public class Get {
    static <T> T type(Class<T> type, Object object) {
        if (object == null || type.isInstance(object)) {
            return type.cast(object);
        } else {
            return null;
        }
    }

    static <T> T type(Class<T> type, Map<?, ?> map, String key) {
        if (map == null) {
            return null;
        }

        Object object = map.get(key);

        return Get.type(type, object);
    }

    static <T> T type(Class<T> type, List<?> list, int index) {
        if (list == null || index < 0 || index > list.size()) {
            return null;
        }

        Object object = list.get(index);

        return Get.type(type, object);
    }

    static <T extends Number> T type(Class<T> type, Number number) {
        if (number == null) {
            return null;
        }

        if (type.isAssignableFrom(Number.class)) {
            return type.cast(number);
        }

        if(type.isAssignableFrom(Byte.class)) {

            return type.cast(number.byteValue());

        } else if (type.isAssignableFrom(Short.class)) {

            return type.cast(number.shortValue());

        } else if (type.isAssignableFrom(Integer.class)) {

            return type.cast(number.intValue());

        } else if (type.isAssignableFrom(Long.class)) {

            return type.cast(number.longValue());

        } else if (type.isAssignableFrom(Float.class)) {

            return type.cast(number.floatValue());

        } else if (type.isAssignableFrom(Double.class)) {

            return type.cast(number.doubleValue());

        }

        return null;
    }
}
